@@ -20,13 +20,14 @@ class Bid:
   delivery_date: datetime.datetime
   decline_reason: str
   bid_histories: List[BidHistory]
-  origin_deadhead: float 
   porus_truck_id: uuid.UUID 
   truck_lane_id: uuid.UUID
   distance: float
   origin_city: str
   origin_state: str
-  origin_zip: str
   dest_city: str
   dest_state: str
-  dest_zip: str
+  origin_zip: str = field(default=None)
+  origin_deadhead: float = field(default=None)
+  dest_zip: str = field(default=None)
+  invite_emailed_at: datetime.datetime = field(default=None)
