@@ -26,11 +26,12 @@ class BidSchema(CamelCaseSchema):
   distance = fields.Float(allow_none=True)
   origin_city = fields.String()
   origin_state = fields.String()
-  origin_zip = fields.String()
+  origin_zip = fields.String(allow_none=True)
   dest_city = fields.String()
   dest_state = fields.String()
-  dest_zip = fields.String()
-
+  dest_zip = fields.String(allow_none=True)
+  invite_emailed_at = fields.DateTime(allow_none=True)
+  
   @post_load
   def make_bid(self, data, **kwargs):
       return Bid(**data)
