@@ -55,7 +55,14 @@ class CarrierSchema(CamelCaseSchema):
   lanes = fields.List(fields.Nested(LaneSchema))
   equipment_preferences = fields.List(fields.String)
   no_dispatch = fields.Boolean(allow_none=True)
-  
+  contacts = fields.List(fields.Nested(ContactSchema, allow_none=True))
+  vetting_authority_display = fields.String(allow_none=True)
+  vetting_insurance_display = fields.String(allow_none=True)
+  vetting_operations_display = fields.String(allow_none=True)
+  vetting_safety_display = fields.String(allow_none=True)
+  vetting_overall_display = fields.String(allow_none=True)
+  last_vetting_time = fields.Date(allow_none=True)
+
   @post_load
   def make_bid(self, data, **kwargs):
       return Carrier(**data)
