@@ -8,12 +8,13 @@ class ContactSchema(CamelCaseSchema):
 
   id = fields.UUID(allow_none=True)
   carrier_id = fields.UUID(allow_none=True)
-  first_name = fields.String()
+  first_name = fields.String(allow_none=True)
   last_name = fields.String(allow_none=True)
   phone = fields.String(allow_none=True)
   email_address = fields.Email()
   mobile = fields.String(allow_none=True)
   primary_contact = fields.Boolean(allow_none=True, missgin=False)
+  is_mail_reciever: bool = fields.Boolean(allow_none=True, missgin=False)
 
   @post_load
   def make_bid(self, data, **kwargs):
