@@ -45,13 +45,16 @@ class Config(object):
   ALJEX_LOADS_BUCKET = 'aljex-loads-dev'
   KNOWN_CLIENT_FILE_EXTENSIONS = {
     'surgetransportation.com': '6507',
-    'simplegx.com': '7084',
+    'simplelgx.com': '7084',
     'engaged': '7147',
     'amstanc4activecarrierlist': '7267',
     'us foods xlsextract': '7582',
     'clservicesinc.com': '7310',
     'zengistics': '7649'
   }
+  BID_COUNTER_FAILURE_SNS_CLASS_NAME = 'com.cargochief.sdk.bookingagent.sns.BidCounterFailureNotification'
+  BOOKING_AGENT_SNS_ARN = 'arn:aws:sns:us-west-1:791608169866:booking-agent-sns-test'
+  CARRIER_HUB_SNS_ARN = 'arn:aws:sns:us-west-1:791608169866:carrier-hub-sns-test'
 
   # Database
   DB_USERNAME = os.getenv('DB_USERNAME')
@@ -60,6 +63,12 @@ class Config(object):
   DB_PASSWORD = os.getenv('DB_PASSWORD')
   DB_NAME = os.getenv('DB_NAME')
 
+  # Services
+  CARRIER_HUB_URL = os.environ.get('CARRIER_HUB_URL')
+  CARRIER_HUB_AUTH_TOKEN = os.environ.get("CARRIER_HUB_AUTH_TOKEN")
+  DD_API_KEY=os.environ.get('DD_API_KEY')
+  DD_SITE=os.environ.get('DD_SITE')
+
 class LocalConfig(Config):
   """Configurations for running and debugging locally, with a separate local database."""
   LOCATION_REDIS_URL='redis://localhost:6379'
@@ -93,13 +102,15 @@ class ProductionConfig(Config):
   ALJEX_LOADS_BUCKET = 'aljex-loads-prod'
   KNOWN_CLIENT_FILE_EXTENSIONS = {
     'surgetransportation.com': '6615',
-    'simplegx.com': '7084',
+    'simplelgx.com': '7084',
     'engaged': '7147',
     'amstanc4activecarrierlist': '7267',
     'us foods xlsextract': '7582',
     'clservicesinc.com': '7310',
     'zengistics': '7649'
   }
+  BOOKING_AGENT_SNS_ARN = 'arn:aws:sns:us-west-1:791608169866:booking-agent-sns-prod'
+  CARRIER_HUB_SNS_ARN = 'arn:aws:sns:us-west-1:791608169866:carrier-hub-sns-prod'
 
 config_options = {
     'local': LocalConfig,
