@@ -37,8 +37,10 @@ class LoadFieldConstants:
   WEIGHT = 'weight'
   ORIGIN_POSTCODE = 'originPostcode'
   DESTINATION_POSTCODE = 'destinationPostcode'
+  REQUEST_ID = 'requestId'
 
 class FileType:
 
   SINGLE_ROW = 'single_row'
   DUAL_ROW = 'dual_row'
+  ALJEX_FILE = 'aljex_file'
\ No newline at end of file
