@@ -1,9 +1,8 @@
 import psycopg2
-import os
 
 from cc_py_commons.config.env import app_config
 
-from cc_py_commons.utils.logger import logger
+from cc_py_commons.utils.logger_v2 import logger
 
 db_host = app_config.DB_HOST
 db_user = app_config.DB_USERNAME
