@@ -1,30 +1,43 @@
 import googlemaps
+import json
 
 from cc_py_commons.config.env import app_config
 from cc_py_commons.utils.redis import location_db_conn, distance_db_conn, timezone_db_conn
 from ast import literal_eval
 
 def get_location(city, state, zipcode, logger):
+  return get_location_with_country(city, state, zipcode, None, logger)
+
+def get_location_with_country(city, state, zipcode, country, logger):
   from_cache = False
-  pc_miler_can_be_called = False
   data = __get_location_from_cache(city, state, zipcode, logger)
 
-  if data and data.get('postcode') and data.get('country'):
-    from_cache = True
-  else:
-    data = None
-
+  if data:
+    if data.get('country') and (not zipcode or zipcode == data.get('postcode')):
+      from_cache = True
+    else:
+      data = None
+      
   if not data:
-    logger.debug(f"geolocate.get_location - Couldn't find location: {city},{state} {zipcode} in cache.")
-    data = __get_google_location(city, state, zipcode, logger)
-    if not data:
-      data = __get_google_location(city=None, state=None, zipcode=zipcode, logger=logger)
+    logger.debug(json.dumps({
+      'message': 'Could not find location in cache',
+      'city': city,
+      'state': state,
+      'postcode': zipcode,
+      'country': country,
+      'cache_key': __get_location_string(city, state, zipcode) 
+    }))
+    data = __get_google_location(city, state, zipcode, country, logger)
+
+  if not data and zipcode:
+    from_cache = False
+    data = __get_google_location(city=None, state=None, zipcode=zipcode, country=None, logger=logger)
 
   if data:
     if not from_cache:
       __cache_location(city, state, zipcode, data, logger)
   else:
-    logger.debug(f"geolocate.get_location - Google returned no result for ({city}, {state}, {zipcode})")
+    logger.debug(f"geolocate.get_location - Google returned no result for ({city}, {state}, {zipcode}, {country})")
 
   return data
 
@@ -82,7 +95,10 @@ def __get_google_distance(origin_latitude, origin_longitude, destination_latitud
     gmaps = googlemaps.Client(key=app_config.GOOGLE_API_KEY)
     origins = [f'{origin_latitude} {origin_longitude}']
     destinations = [f'{destination_latitude} {destination_longitude}']
-    response = gmaps.distance_matrix(origins,destinations,mode="driving",units="imperial")
+    response = gmaps.distance_matrix(origins,
+                                     destinations,
+                                     mode="driving",
+                                     units="imperial")
     if response and response['rows'][0]['elements'][0].get('distance', None):
       distance_in_meters = response['rows'][0]['elements'][0]['distance']['value']
       distance = distance_in_meters / 1609
@@ -91,7 +107,7 @@ def __get_google_distance(origin_latitude, origin_longitude, destination_latitud
     distance = None
   return distance
 
-def __get_google_location(city, state, zipcode, logger):
+def __get_google_location(city, state, zipcode, country, logger):
   try:
     loc_str = ''
 
@@ -110,6 +126,12 @@ def __get_google_location(city, state, zipcode, logger):
 
       loc_str = loc_str + zipcode
 
+    if country:
+      if len(loc_str) > 0:
+        loc_str = loc_str + ', '
+
+      loc_str = loc_str + country
+
     def __parse_response(response):
       if not response or len(response) == 0:
         return None
@@ -231,6 +253,8 @@ def __get_google_location(city, state, zipcode, logger):
     response = gmaps.geocode(loc_str)
     
     if response:
+      response = [results for results in response if 'country' not in results.get('types')]
+
       if len(response) > 1:
         logger.warning(f"Google returned multiple matches for {loc_str}. Selecting a single address.")
         selected_address = None
@@ -275,14 +299,17 @@ def __cache_location(city, state, zipcode, location_data, logger):
 
 def __get_location_from_cache(city, state, zipcode, logger):
   location = None
+
   try:
-    location_string = __get_location_string(city, state, zipcode)
-    location = location_db_conn.get(location_string)
+    cache_key = __get_location_string(city, state, zipcode) 
+    location = location_db_conn.get(cache_key)
+
     if location:
       location = literal_eval(location.decode('utf-8'))
   except Exception as e:
     logger.warn("geolocate.__get_location_from_cache: Error while getting location from cache", e)
     location = None
+
   return location
 
 def __get_location_string(city, state, zipcode):
@@ -317,7 +344,7 @@ def __truncate(number):
   return int(number * 1000000) / 1000000
 
 def __cache_timezone(timezone_cache_key, timezone, logger):
-  timezone_db_conn.set(timezone_cache_key, timezone)
+  timezone_db_conn.set(timezone_cache_key, json.dumps(timezone))
 
 def __get_timezone_from_cache(timezone_cache_key, logger):
   timezone = None
