@@ -15,5 +15,8 @@ EQUIPMENT_TYPES = {
   "RGN": "86bdf40d-539f-4e70-90a2-c5471f2604c3",
   "CONTAINER": "42a8e1cf-c85b-4357-b229-a09c163b72f7",
   "HIGH_CUBE_CONTAINER": "42a8e1cf-c85b-4357-b229-a09c163b72f7",
-  "POWER ONLY": "e9ced401-93d9-4bc9-9342-d020481133dc"
+  "POWER ONLY": "e9ced401-93d9-4bc9-9342-d020481133dc",
+  "BOX": "f5d9ac97-c088-473f-9ed1-f77548f6aeb1",
+  "SPRINTER": "31d9c357-54a7-4df7-8bc6-d197c6e938a4",
+  "STRAIGHT": "d1c3d5b2-48a9-420e-8c79-64e5a78383ec"
 }
