@@ -1,7 +1,7 @@
 import os
 import requests
 
-from cc_py_commons.utils.logger import logger
+from cc_py_commons.utils.logger_v2 import logger
 
 FREIGHT_HUB_URL = os.environ.get('FREIGHT_HUB_URL')
 FREIGHT_HUB_TOKEN = os.environ.get("FREIGHT_HUB_TOKEN")
