@@ -1,7 +1,7 @@
 import os
 import requests
 
-from cc_py_commons.utils.logger import logger
+from cc_py_commons.utils.logger_v2 import logger
 
 MERCURY_URL = os.environ.get("MERCURY_URL")
 MERCURY_TOKEN = os.environ.get("MERCURY_TOKEN")
