@@ -1,7 +1,7 @@
 import json
 
 from cc_py_commons.sns.sns_service import SnsService
-from cc_py_commons.utils.logger import logger
+from cc_py_commons.utils.logger_v2 import logger
 
 class BookingAssistantFlowNotification:
 
