@@ -9,7 +9,7 @@ class ImportMovementsNotification:
 
   def send(self, mcleod_token, c4_account_id, company_id):
     message = '{' + f'"accountId" : {c4_account_id}, ' \
-                    f'"mcleodToken" : {mcleod_token}, ' \
+                    f'"mcleodToken" : "{mcleod_token}", ' \
                     f'"companyId": "{company_id}", ' \
                     f'"subject" : "{self._app_config.IMPORT_MOVEMENTS_SNS_SUBJECT}", ' \
                     f'"className":  "{self._app_config.IMPORT_MOVEMENTS_SNS_CLASS_NAME}"' + '}'
