@@ -2,11 +2,11 @@ import json
 
 from cc_py_commons.config.env import app_config
 from cc_py_commons.sqs.sqs_service import SqsService
-from cc_py_commons.utils.logger import logger
+from cc_py_commons.utils.logger_v2 import logger
 
 class BookingAssistantFlowEvent:
 
-	def send(self, user_id, load, params):
+	def send(self, user_id, load, params, capacity_search_equipments, request_id):
 		'''
 		Sends and event to the Booking Assistant Flow SQS queue specified in the config.
 		Returns the messageId of the enqueued message for later retrieval.
@@ -15,6 +15,8 @@ class BookingAssistantFlowEvent:
 			'userId': user_id,
 			'loadDTO': load,
 			'payload': params,
+			'capacitySearchEquipments': capacity_search_equipments,
+			'requestId': request_id,
 			'subject': f'{app_config.BOOKING_ASSISTANT_SNS_SUBJECT}',
 			'className': f'{app_config.BOOKING_ASSISTANT_SNS_CLASS_NAME}'
 		}
