@@ -1,4 +1,4 @@
-from uuid import UUID
+from uuid import UUID, uuid4
 import datetime
 import unittest
 
@@ -10,6 +10,7 @@ from cc_py_commons.transactions.map_transaction import from_load
 class TestMapTransaction(unittest.TestCase):
 
 	def setUp(self):
+
 		self.valid_load = Load(reference_number='20067', 
 			customer_id=5876, 
 			origin=Location(city='PLYMOUTH', state='NC', postcode='27962', county=None, country=None, latitude=None, longitude=None), 
@@ -53,8 +54,10 @@ class TestMapTransaction(unittest.TestCase):
 			truck_search_id=None, 
 			id=None,
 			load_number=None, 
-			mcleod_movement_id='20067')
+			mcleod_movement_id='20067',
+			request_id=uuid4())
 
 	def test_valid_load(self):
 		t = from_load(self.valid_load)
 		self.assertEqual(self.valid_load.reference_number, t.reference_number)
+		self.assertEqual(self.valid_load.request_id, t.request_id)
