@@ -1,7 +1,8 @@
+import json, traceback
 from dataclasses import fields
 from cc_py_commons.transactions.transaction import Transaction
 from cc_py_commons.utils.get_delivery_date import execute as get_delivery_date
-
+from cc_py_commons.utils.logger_v2 import logger
 
 def from_load(load):
 	"""Takes a freight-hub load and maps it to a pricing load (Transaction)"""
@@ -13,15 +14,18 @@ def from_load(load):
 		if value:
 			trans_data[field.name] = value
 
-	if not trans_data.get('delivery_date'):
+	if not trans_data.get('delivery_date') and load.pickup_date:
 		trans_data['delivery_date'] = get_delivery_date(pickup_date=load.pickup_date, distance_in_miles=load.distance)
+
 	trans_data['equipment'] = load.equipment_description
 	trans_data['all_in_cost'] = load.rate # all in cost may change at booking
 	trans_data['carrier_id'] = load.carrier_id
 	trans_data['target_pay'] = load.rate # target_pay is what the broker listed the load for
-	trans_data['multi_stop'] = load.stops
+	trans_data['multi_stop'] = load.stops_count
 	trans_data['team_service'] = load.team_service_required
-
+	trans_data['partial_load'] = load.partial_load
+	trans_data['ltl'] = load.ltl
+	
 	if isinstance(load.origin, dict):
 		trans_data['origin_city'] = load.origin['city']
 		trans_data['origin_state'] = load.origin['state']
@@ -55,9 +59,20 @@ def from_load(load):
 	trans_data['pickup_open_time'] = load.pickup_open_time
 	trans_data['pickup_close_time'] = load.pickup_close_time
 	trans_data['freight_hub_load_id'] = load.id
+	trans_data['revenue_code'] = load.revenue_code
 	if load.special_instructions:
 		trans_data['comments'] = load.special_instructions
 	if load.linear_feet:
 		trans_data['linear_feet'] = load.linear_feet
-	transaction = Transaction(**trans_data)
+
+	try:
+		transaction = Transaction(**trans_data)
+	except Exception as e:
+		logger.warning(json.dumps({
+			'message': 'Failed to map Transaction schema object',
+			'error': str(e),
+			'stacktrace': traceback.format_exc()
+		}))
+		return None
+	
 	return transaction
