@@ -106,3 +106,6 @@ class Transaction:
     freight_hub_load_id: uuid.UUID = field(default=None)
     partial_load: bool = field(default=False)
     linear_feet: int = field(default=None)
+    ltl: bool = field(default=False)
+    revenue_code: str = field(default=None)
+    request_id: uuid.UUID = field(default=None)
