@@ -102,7 +102,11 @@ class TransactionSchema(CamelCaseSchema):
 	freight_hub_load_id = fields.UUID(allow_none=True)
 	partial_load = fields.Boolean(allow_none=True)
 	linear_feet = fields.Integer(allow_none=True)
-
+	ltl = fields.Boolean(allow_none=True)
+	revenue_code = fields.String(allow_none=True)
+	request_id = fields.UUID(allow_none=True)
+	mcleod_movement_id = fields.String(allow_none=True)
+	
 	@post_load
 	def classify(self, data, **kwargs):
 		print(f"post_load - {data}")
