@@ -5,6 +5,12 @@ def kg_to_lbs(weight_in_kg):
 		weight_in_lbs = round(weight_in_kg * 2.2046, 2)
 	return weight_in_lbs
 
+def tons_to_lbs(weight_in_tons):
+	weight_in_lbs = None
+	if weight_in_tons:
+		weight_in_lbs = round(weight_in_tons * 2000, 2)
+	return weight_in_lbs
+
 def inch_to_ft(length_in_inch):
 	length_in_ft = None
 	if length_in_inch:
