@@ -5,7 +5,7 @@ from datetime import timedelta
 from cc_py_commons.config.env import app_config
 
 
-def execute(pickup_date, distance_in_miles):
+def execute(pickup_date, distance_in_miles=None):
 	minimum_miles_per_day = app_config.MINIMUM_MILES_PER_DAY
 
 	if distance_in_miles:
