@@ -1,7 +1,7 @@
 import os
 import pandas as pd
 
-from cc_py_commons.utils.logger import logger
+from cc_py_commons.utils.logger_v2 import logger
 
 
 def load_data(filename):
