@@ -6,6 +6,7 @@ from logging.handlers import SysLogHandler
 
 from cc_py_commons.config.env import env_name, app_config
 
+## DEPRECATED. Use logger_v2 instead
 class ContextFilter(logging.Filter):
   hostname = socket.gethostname()
 
@@ -28,7 +29,10 @@ def _config_logger():
     syslog = SysLogHandler(address=('logs3.papertrailapp.com', 10024))
 
   syslog.setFormatter(formatter)
-  logger.addHandler(syslog)
+
+  if not logger.handlers:
+    logger.addHandler(syslog)
+
   return logger
 
 logger = _config_logger()
